#
# -*- encoding: utf-8 -*-

"""User defined sort order sample extension."""

import sort_order
import string

name_to_yomigana = {}

class SortOrderNumbering(sort_order.SortOrderBase):
    """Numbering sort order.

    Only whole Yomigana is all numbers are sorted.
    Because inheriting SortOrderBase and not SortOrderRegacy,
    NFD normalization is not done. 
    """
    global name_to_yomigana

    def register_entry(self, dict_of_entries):
        """
        """
        name_to_yomigana.update(dict_of_entries)
        return

    def get_string_to_sort(self, entry_name):
        s = self.get_yomigana(entry_name)
        if not s.isdigit():
            return s.lower()
        return '{0:09d}'.format(int(s))

    def get_group_name(self, entry_name):
        """Return the group name of the given entry"""
        s = self.get_string_to_sort(entry_name)
        if s[0] in string.ascii_letters:
            return u'ASCII Alphabets'
        return u"Others (including numbered Yomigana)"

    def get_yomigana(self, entry_name):
        """Internal function"""
        n = entry_name
        if n in name_to_yomigana:
            n = name_to_yomigana[n]
        return n

def setup(app):
    """Extends Sphinx as we want

    @param app sphinx.application.Sphinx object to use add builder or so.
    """
    sort_order.setup(app)
    app.add_config_value('sort_order', SortOrderNumbering(), 'env')
    return

